Start to make use of the proper PEB structure for process
information.

diff --git a/include/thread.h b/include/thread.h
index 2e4798d..ff8e89d 100644
--- a/include/thread.h
+++ b/include/thread.h
@@ -24,7 +24,6 @@
 #include "winternl.h"
 #include "wine/windef16.h"
 
-struct _PDB;
 struct __EXCEPTION_FRAME;
 struct _SECURITY_ATTRIBUTES;
 struct tagSYSLEVEL;
@@ -64,7 +63,7 @@
     HQUEUE16     queue;          /* 1!-  28 Message queue (NT: DWORD ActiveRpcHandle)*/
     WORD         pad1;           /* --n  2a */
     LPVOID      *tls_ptr;        /* 1--  2c Pointer to TLS array */
-    struct _PDB *process;        /* 12-  30 owning process (win95: PDB; nt: NTPEB !!) */
+    PEB         *Peb;            /* 12-  30 owning process PEB */
     DWORD	 flags;	         /* 1-n  34 */
     DWORD        exit_code;      /* 1--  38 Termination status */
     WORD         teb_sel;        /* 1--  3c Selector to TEB */